.. _testing:

Testing
=======

.. autoclass:: falcon.testing.TestCase
    :members:

.. autoclass:: falcon.testing.Result
    :members:

.. autoclass:: falcon.testing.SimpleTestResource
    :members:

.. autoclass:: falcon.testing.StartResponseMock
    :members:

.. automodule:: falcon.testing
    :members: capture_responder_args, rand_string, create_environ

Deprecated
----------

.. autoclass:: falcon.testing.TestBase
    :members:

.. autoclass:: falcon.testing.TestResource
    :members:
